@@ -20,7 +20,6 @@ from datetime import datetime
 CURRENTCOST = "currentcost"
 TIMESERIES = "timeseries"
 ERROR = "error"
-TOPICS = (CURRENTCOST, ERROR)
 TTY_CONNECTION_PROBLEM = "CurrentCost %s in %s: TTY connection problem: %s \
 is unreachable. Retry connection in 5 seconds."
 TTY_TRYING_CONNECTION = "CurrentCost %s in %s: Trying to connect to %s."
@@ -38,7 +37,7 @@ CURRENTCOST_UNICODE_ERROR = "Bad message sent from currentcost, invalid ASCII"
 INCORRECT_MESSAGE = "Receive incorrect message => %s"
 MISSING_SITE_ID = "missing siteID in %s"
 MISSING_VARIABLE_ID = "missing variableID in %s"
-MISSING_MESSAGE = "missing message in %s"
+MISSING_VALUE = "missing value in %s"
 MISSING_DATE = "missing date in %s"
 MISSING_DST_TIMEZONE = "missing dstTimezone in %s"
 MISSING_NON_DST_TIMEZONE = "missing nonDstTimezone in %s"
